summaryrefslogtreecommitdiffstats
path: root/src/H5SLprivate.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2006-03-11 21:59:01 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2006-03-11 21:59:01 (GMT)
commit1f41dfca050d557d66341372529214a8ca690c89 (patch)
tree09b4e6ef81589cea1bf79efa9374944e2784b14d /src/H5SLprivate.h
parente054e736aa115ab749658c454701229b1656569d (diff)
downloadhdf5-1f41dfca050d557d66341372529214a8ca690c89.zip
hdf5-1f41dfca050d557d66341372529214a8ca690c89.tar.gz
hdf5-1f41dfca050d557d66341372529214a8ca690c89.tar.bz2
[svn-r12078] Purpose:
New features Description: Add "find node greater than or equal to key" and "remove first" operations to skip lists. Platforms tested: FreeBSD 4.11 (sleipnir) Too minor to require h5committest
Diffstat (limited to 'src/H5SLprivate.h')
-rw-r--r--src/H5SLprivate.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/H5SLprivate.h b/src/H5SLprivate.h
index bf8d3b7..d37f130 100644
--- a/src/H5SLprivate.h
+++ b/src/H5SLprivate.h
@@ -44,7 +44,8 @@ typedef enum {
H5SL_TYPE_HADDR, /* Skip list keys are 'haddr_t's */
H5SL_TYPE_STR, /* Skip list keys are 'char *'s (ie. strings) */
H5SL_TYPE_HSIZE, /* Skip list keys are 'hsize_t's */
- H5SL_TYPE_UNSIGNED /* Skip list keys are 'unsigned's */
+ H5SL_TYPE_UNSIGNED, /* Skip list keys are 'unsigned's */
+ H5SL_TYPE_SIZE /* Skip list keys are 'size_t's */
} H5SL_type_t;
/**********/
@@ -64,8 +65,10 @@ H5_DLL size_t H5SL_count(H5SL_t *slist);
H5_DLL herr_t H5SL_insert(H5SL_t *slist, void *item, const void *key);
H5_DLL H5SL_node_t *H5SL_add(H5SL_t *slist, void *item, const void *key);
H5_DLL void *H5SL_remove(H5SL_t *slist, const void *key);
+H5_DLL void *H5SL_remove_first(H5SL_t *slist);
H5_DLL void *H5SL_search(H5SL_t *slist, const void *key);
H5_DLL void *H5SL_less(H5SL_t *slist, const void *key);
+H5_DLL void *H5SL_greater(H5SL_t *slist, const void *key);
H5_DLL H5SL_node_t *H5SL_find(H5SL_t *slist, const void *key);
H5_DLL H5SL_node_t *H5SL_first(H5SL_t *slist);
H5_DLL H5SL_node_t *H5SL_next(H5SL_node_t *slist_node);